@@ -3,7 +3,7 @@
  *
  * MIT license
  *
- * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ * Copyright (c) 2018-2022 Dariusz Depta Engos Software
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -15,7 +15,7 @@
  *
  * Apache license, Version 2.0
  *
- * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ * Copyright (c) 2018-2022 Dariusz Depta Engos Software
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@
  * limitations under the License.
  */
 
-//! Item definition evaluator.
+//! Builder for item definition evaluators.
 
 use crate::errors::{err_empty_feel_name, err_unsupported_feel_type};
 use dmntk_common::Result;
@@ -41,7 +41,7 @@ use dmntk_model::model::{Definitions, ItemDefinition, ItemDefinitionType, NamedE
 use std::collections::HashMap;
 
 /// Type of closure that evaluates input data conformant with item definition.
-type ItemDefinitionEvaluatorFn = Box<dyn Fn(&Value, &ItemDefinitionEvaluator) -> Value>;
+type ItemDefinitionEvaluatorFn = Box<dyn Fn(&Value, &ItemDefinitionEvaluator) -> Value + Send + Sync>;
 
 /// Item definition evaluator.
 #[derive(Default)]
@@ -473,166 +473,157 @@ mod tests {
   use dmntk_feel::{value_null, value_number, FeelDate, FeelDateTime, FeelDaysAndTimeDuration, FeelNumber, FeelTime, FeelYearsAndMonthsDuration, Name};
 
   /// Utility function for building item definition evaluator from definitions.
-  fn build_evaluator(xml: &str, source: &str) -> ItemDefinitionEvaluator {
+  fn build_evaluator(xml: &str) -> ItemDefinitionEvaluator {
     let mut evaluator = ItemDefinitionEvaluator::default();
-    evaluator.build(&dmntk_model::parse(xml, source).unwrap()).unwrap();
+    evaluator.build(&dmntk_model::parse(xml).unwrap()).unwrap();
     evaluator
   }
 
   #[test]
   fn test_evaluate_input_data_0101_1() {
-    let evaluator = build_evaluator(DMN_0101, "file:///0101.dmn");
+    let evaluator = build_evaluator(DMN_0101);
     let context_str = r#"{ Customer Name : "Whistler" }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Customer", "Name"])).unwrap();
-    assert_eq!(
-      Value::String("Whistler".to_string()),
-      evaluator.eval(&"tCustomerName".to_string(), value).unwrap()
-    );
+    assert_eq!(Value::String("Whistler".to_string()), evaluator.eval("tCustomerName", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0101_2() {
-    let evaluator = build_evaluator(DMN_0101, "file:///0101.dmn");
+    let evaluator = build_evaluator(DMN_0101);
     let context_str = r#"{ Customer Name : 12000 }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Customer", "Name"])).unwrap();
     assert_eq!(
       value_null!("expected type 'string', actual type is 'number' in value '12000'"),
-      evaluator.eval(&"tCustomerName".to_string(), value).unwrap()
+      evaluator.eval("tCustomerName", value).unwrap()
     );
   }
 
   #[test]
   fn test_evaluate_input_data_0102_1() {
-    let evaluator = build_evaluator(DMN_0102, "file:///0102.dmn");
+    let evaluator = build_evaluator(DMN_0102);
     let context_str = r#"{ Monthly Salary : 12000.00 }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Monthly", "Salary"])).unwrap();
-    assert_eq!(value_number!(12_000), evaluator.eval(&"tMonthlySalary".to_string(), value).unwrap());
+    assert_eq!(value_number!(12_000), evaluator.eval("tMonthlySalary", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0102_2() {
-    let evaluator = build_evaluator(DMN_0102, "file:///0102.dmn");
+    let evaluator = build_evaluator(DMN_0102);
     let context_str = r#"{ Monthly Salary : true }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Monthly", "Salary"])).unwrap();
     assert_eq!(
       value_null!("expected type 'number', actual type is 'boolean' in value 'true'"),
-      evaluator.eval(&"tMonthlySalary".to_string(), value).unwrap()
+      evaluator.eval("tMonthlySalary", value).unwrap()
     );
   }
 
   #[test]
   fn test_evaluate_input_data_0103_1() {
-    let evaluator = build_evaluator(DMN_0103, "file:///0103.dmn");
+    let evaluator = build_evaluator(DMN_0103);
     let context_str = r#"{ Is Affordable : true }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Is", "Affordable"])).unwrap();
-    assert_eq!(Value::Boolean(true), evaluator.eval(&"tIsAffordable".to_string(), value).unwrap());
+    assert_eq!(Value::Boolean(true), evaluator.eval("tIsAffordable", value).unwrap());
     let context_str = r#"{ Is Affordable : false }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Is", "Affordable"])).unwrap();
-    assert_eq!(Value::Boolean(false), evaluator.eval(&"tIsAffordable".to_string(), value).unwrap());
+    assert_eq!(Value::Boolean(false), evaluator.eval("tIsAffordable", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0103_2() {
-    let evaluator = build_evaluator(DMN_0103, "file:///0103.dmn");
+    let evaluator = build_evaluator(DMN_0103);
     let context_str = r#"{ Is Affordable : "Yes" }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Is", "Affordable"])).unwrap();
     assert_eq!(
       value_null!(r#"expected type 'boolean', actual type is 'string' in value '"Yes"'"#),
-      evaluator.eval(&"tIsAffordable".to_string(), value).unwrap()
+      evaluator.eval("tIsAffordable", value).unwrap()
     );
   }
 
   #[test]
   fn test_evaluate_input_data_0104_1() {
-    let evaluator = build_evaluator(DMN_0104, "file:///0104.dmn");
+    let evaluator = build_evaluator(DMN_0104);
     let context_str = r#"{ Birthday : date("1982-04-12") }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Birthday"])).unwrap();
-    assert_eq!(
-      Value::Date(FeelDate::new(1982, 4, 12)),
-      evaluator.eval(&"tBirthday".to_string(), value).unwrap()
-    );
+    assert_eq!(Value::Date(FeelDate::new(1982, 4, 12)), evaluator.eval("tBirthday", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0105_1() {
-    let evaluator = build_evaluator(DMN_0105, "file:///0105.dmn");
+    let evaluator = build_evaluator(DMN_0105);
     let context_str = r#"{ Delivery Time : time("18:35:23") }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Delivery", "Time"])).unwrap();
     assert_eq!(
       Value::Time(FeelTime::new_hms_opt(18, 35, 23, 0).unwrap()),
-      evaluator.eval(&"tDeliveryTime".to_string(), value).unwrap()
+      evaluator.eval("tDeliveryTime", value).unwrap()
     );
   }
 
   #[test]
   fn test_evaluate_input_data_0106_1() {
-    let evaluator = build_evaluator(DMN_0106, "file:///0106.dmn");
+    let evaluator = build_evaluator(DMN_0106);
     let context_str = r#"{ Appointment : date and time("2021-10-12T18:35:23") }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Appointment"])).unwrap();
     assert_eq!(
       Value::DateTime(FeelDateTime::new(FeelDate::new(2021, 10, 12), FeelTime::new_hms_opt(18, 35, 23, 0).unwrap())),
-      evaluator.eval(&"tAppointment".to_string(), value).unwrap()
+      evaluator.eval("tAppointment", value).unwrap()
     );
   }
 
   #[test]
   fn test_evaluate_input_data_0107_1() {
-    let evaluator = build_evaluator(DMN_0107, "file:///0107.dmn");
+    let evaluator = build_evaluator(DMN_0107);
     let context_str = r#"{ Course Duration : duration("P2DT3H") }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Course", "Duration"])).unwrap();
     assert_eq!(
       Value::DaysAndTimeDuration(FeelDaysAndTimeDuration::default().second(183600).build()),
-      evaluator.eval(&"tCourseDuration".to_string(), value).unwrap()
+      evaluator.eval("tCourseDuration", value).unwrap()
     );
   }
 
   #[test]
   fn test_evaluate_input_data_0108_1() {
-    let evaluator = build_evaluator(DMN_0108, "file:///0108.dmn");
+    let evaluator = build_evaluator(DMN_0108);
     let context_str = r#"{ Growth Duration : duration("P2Y5M") }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Growth", "Duration"])).unwrap();
     assert_eq!(
       Value::YearsAndMonthsDuration(FeelYearsAndMonthsDuration::new_ym(2, 5)),
-      evaluator.eval(&"tGrowthDuration".to_string(), value).unwrap()
+      evaluator.eval("tGrowthDuration", value).unwrap()
     );
   }
 
   #[test]
   fn test_evaluate_input_data_0201_1() {
-    let evaluator = build_evaluator(DMN_0201, "file:///0201.dmn");
+    let evaluator = build_evaluator(DMN_0201);
     let context_str = r#"{ Customer Name : "Bloomberg" }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Customer", "Name"])).unwrap();
-    assert_eq!(
-      Value::String("Bloomberg".to_string()),
-      evaluator.eval(&"tCustomerName".to_string(), value).unwrap()
-    );
+    assert_eq!(Value::String("Bloomberg".to_string()), evaluator.eval("tCustomerName", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0202_1() {
-    let evaluator = build_evaluator(DMN_0202, "file:///0202.dmn");
+    let evaluator = build_evaluator(DMN_0202);
     let context_str = r#"{ Monthly Salary : 12000.00 }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Monthly", "Salary"])).unwrap();
-    assert_eq!(value_number!(12_000), evaluator.eval(&"tMonthlySalary".to_string(), value).unwrap());
+    assert_eq!(value_number!(12_000), evaluator.eval("tMonthlySalary", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0301_1() {
-    let evaluator = build_evaluator(DMN_0301, "file:///0301.dmn");
+    let evaluator = build_evaluator(DMN_0301);
     let context_str = r#"{ Loan : { principal: 10, rate: 60, termMonths: 28 } }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Loan"])).unwrap();
@@ -641,12 +632,12 @@ mod tests {
     ctx.set_entry(&"rate".into(), value_number!(60));
     ctx.set_entry(&"termMonths".into(), value_number!(28));
     let expected = Value::Context(ctx);
-    assert_eq!(expected, evaluator.eval(&"tLoan".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tLoan", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0401_1() {
-    let evaluator = build_evaluator(DMN_0401, "file:///0401.dmn");
+    let evaluator = build_evaluator(DMN_0401);
     let context_str = r#"{ Items : ["Mercury", "Venus", "Earth", "Mars"] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -656,12 +647,12 @@ mod tests {
       Value::String("Earth".to_string()),
       Value::String("Mars".to_string()),
     ]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0402_1() {
-    let evaluator = build_evaluator(DMN_0402, "file:///0402.dmn");
+    let evaluator = build_evaluator(DMN_0402);
     let context_str = r#"{ Items : [9000.00, 10000.00, 11000.00, 12000.00, 13000.00] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -672,12 +663,12 @@ mod tests {
       value_number!(12_000),
       value_number!(13_000),
     ]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0403_1() {
-    let evaluator = build_evaluator(DMN_0403, "file:///0403.dmn");
+    let evaluator = build_evaluator(DMN_0403);
     let context_str = r#"{ Items : [true, false, false, true, true] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -688,12 +679,12 @@ mod tests {
       Value::Boolean(true),
       Value::Boolean(true),
     ]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0404_1() {
-    let evaluator = build_evaluator(DMN_0404, "file:///0404.dmn");
+    let evaluator = build_evaluator(DMN_0404);
     let context_str = r#"{ Items : [date("2021-10-10"), date("2021-10-11"), date("2021-10-12")] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -702,12 +693,12 @@ mod tests {
       Value::Date(FeelDate::new(2021, 10, 11)),
       Value::Date(FeelDate::new(2021, 10, 12)),
     ]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0405_1() {
-    let evaluator = build_evaluator(DMN_0405, "file:///0405.dmn");
+    let evaluator = build_evaluator(DMN_0405);
     let context_str = r#"{ Items : [time("12:21:35"), time("12:21:36"), time("12:21:37")] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -716,12 +707,12 @@ mod tests {
       Value::Time(FeelTime::new_hms_opt(12, 21, 36, 0).unwrap()),
       Value::Time(FeelTime::new_hms_opt(12, 21, 37, 0).unwrap()),
     ]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0406_1() {
-    let evaluator = build_evaluator(DMN_0406, "file:///0406.dmn");
+    let evaluator = build_evaluator(DMN_0406);
     let context_str = r#"{ Items : [date and time("2021-10-10T21:23:18"), date and time("2021-10-11T12:18:59")] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -729,24 +720,24 @@ mod tests {
       Value::DateTime(FeelDateTime::new(FeelDate::new(2021, 10, 10), FeelTime::new_hms_opt(21, 23, 18, 0).unwrap())),
       Value::DateTime(FeelDateTime::new(FeelDate::new(2021, 10, 11), FeelTime::new_hms_opt(12, 18, 59, 0).unwrap())),
     ]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0407_1() {
-    let evaluator = build_evaluator(DMN_0407, "file:///0407.dmn");
+    let evaluator = build_evaluator(DMN_0407);
     let context_str = r#"{ Items : [duration("P2DT3H")] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
     let expected = Value::List(Values::new(vec![Value::DaysAndTimeDuration(
       FeelDaysAndTimeDuration::default().second(183600).build(),
     )]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0408_1() {
-    let evaluator = build_evaluator(DMN_0408, "file:///0408.dmn");
+    let evaluator = build_evaluator(DMN_0408);
     let context_str = r#"{ Items : [duration("P2Y3M"), duration("P2Y4M")] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -754,12 +745,12 @@ mod tests {
       Value::YearsAndMonthsDuration(FeelYearsAndMonthsDuration::new_ym(2, 3)),
       Value::YearsAndMonthsDuration(FeelYearsAndMonthsDuration::new_ym(2, 4)),
     ]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0501_1() {
-    let evaluator = build_evaluator(DMN_0501, "file:///0501.dmn");
+    let evaluator = build_evaluator(DMN_0501);
     let context_str = r#"{ Items : ["Mercury", "Venus", "Earth"] }"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -768,12 +759,12 @@ mod tests {
       Value::String("Venus".to_string()),
       Value::String("Earth".to_string()),
     ]));
-    assert_eq!(expected, evaluator.eval(&"tItems".to_string(), value).unwrap());
+    assert_eq!(expected, evaluator.eval("tItems", value).unwrap());
   }
 
   #[test]
   fn test_evaluate_input_data_0601_1() {
-    let evaluator = build_evaluator(DMN_0601, "file:///0601.dmn");
+    let evaluator = build_evaluator(DMN_0601);
     let context_str = r#"{Items:[{number:1,name:"One",manager:"John"},{number:2,name:"Two",manager:"Mike"},{number:3,name:"Three",manager:"Bob"}]}"#;
     let context = dmntk_feel_evaluator::evaluate_context(&Default::default(), context_str).unwrap();
     let value = context.get_entry(&Name::new(&["Items"])).unwrap();
@@ -790,6 +781,6 @@ mod tests {
     ctx_3.set_entry(&"name".into(), Value::String("Three".to_string()));
     ctx_3.set_entry(&"manager".into(), Value::String("Bob".to_string()));
     let expected = Value::List(Values::new(vec![Value::Context(ctx_1), Value::Context(ctx_2), Value::Context(ctx_3)]));
-    assert_eq!(Some(expected), evaluator.eval(&"tItems".to_string(), value));
+    assert_eq!(Some(expected), evaluator.eval("tItems", value));
   }
 }
