@@ -3,7 +3,7 @@
  *
  * MIT license
  *
- * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ * Copyright (c) 2018-2022 Dariusz Depta Engos Software
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -15,7 +15,7 @@
  *
  * Apache license, Version 2.0
  *
- * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ * Copyright (c) 2018-2022 Dariusz Depta Engos Software
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,6 +34,7 @@ extern crate dmntk_common;
 extern crate dmntk_feel;
 extern crate dmntk_feel_parser;
 extern crate dmntk_model;
+#[cfg(test)]
 extern crate dmntk_recognizer;
 #[cfg(test)]
 #[macro_use]
@@ -43,32 +44,10 @@ extern crate thiserror;
 
 mod builders;
 mod errors;
-mod eval_bkm;
-mod eval_dec;
-mod eval_dec_service;
 mod model_evaluator;
 
 #[cfg(test)]
 mod tests;
 
-use dmntk_common::Result;
-use dmntk_feel::values::Value;
-use dmntk_feel::Scope;
-pub use eval_bkm::evaluate_business_knowledge_model_by_name;
-pub use eval_dec::evaluate_decision_by_name;
-pub use eval_dec_service::eval_decision_service_by_name;
-
-/// Evaluates the decision table.
-pub fn evaluate_decision_table_from_text(_scope: &Scope, _input: &str) -> Result<Value> {
-  unimplemented!()
-}
-
-/// Evaluates a decision table against specified context.
-pub fn evaluate_decision_table_and_context(_decision_table_input: &str, _context_input: &str) -> Result<Value> {
-  unimplemented!()
-}
-
-/// Evaluates all tests associated with decision table.
-pub fn evaluate_decision_table_and_test(_input: &str, _sep: &str) -> Result<(bool, Value, Value)> {
-  unimplemented!()
-}
+pub use builders::decision_table::build_decision_table_evaluator;
+pub use model_evaluator::ModelEvaluator;
